@@ -10,7 +10,9 @@ import (
 	"strings"
 	"testing"
 
-	"github.com/livebud/bud/package/budfs"
+	"github.com/livebud/bud/package/genfs"
+
+	"github.com/livebud/bud/framework/view/nodemodules"
 
 	"github.com/livebud/bud/package/log/testlog"
 
@@ -18,6 +20,7 @@ import (
 	"github.com/livebud/bud/package/gomod"
 
 	"github.com/livebud/bud/framework/view/dom"
+	"github.com/livebud/bud/internal/dag"
 	"github.com/livebud/bud/internal/is"
 	"github.com/livebud/bud/internal/testdir"
 	"github.com/livebud/bud/internal/versions"
@@ -34,9 +37,8 @@ func TestServeFile(t *testing.T) {
 	is.NoErr(err)
 	svelteCompiler, err := svelte.Load(vm)
 	is.NoErr(err)
-	transformer := transformrt.MustLoad(
-		svelte.NewTransformable(svelteCompiler),
-	)
+	transformer, err := transformrt.Default(log, svelteCompiler)
+	is.NoErr(err)
 	td := testdir.New(dir)
 	td.Files["view/index.svelte"] = `<h1>index</h1>`
 	td.Files["view/about/index.svelte"] = `<h2>about</h2>`
@@ -44,10 +46,10 @@ func TestServeFile(t *testing.T) {
 	is.NoErr(td.Write(ctx))
 	module, err := gomod.Find(dir)
 	is.NoErr(err)
-	bfs := budfs.New(module, log)
-	bfs.FileServer("bud/view", dom.New(module, transformer.DOM))
+	gfs := genfs.New(dag.Discard, module, log)
+	gfs.FileServer("bud/view", dom.New(module, transformer))
 	// Read the wrapped version of index.svelte with node_modules rewritten
-	code, err := fs.ReadFile(bfs, "bud/view/_index.svelte.js")
+	code, err := fs.ReadFile(gfs, "bud/view/_index.svelte.js")
 	is.NoErr(err)
 	is.True(strings.Contains(string(code), `from "/bud/node_modules/svelte/internal"`))
 	is.True(strings.Contains(string(code), `element("h1");`))
@@ -57,7 +59,7 @@ func TestServeFile(t *testing.T) {
 	is.True(strings.Contains(string(code), `hot: new Hot("http://127.0.0.1:35729/bud/hot/view/index.svelte", components)`))
 
 	// Unwrapped version with node_modules rewritten
-	code, err = fs.ReadFile(bfs, "bud/view/index.svelte")
+	code, err = fs.ReadFile(gfs, "bud/view/index.svelte")
 	is.NoErr(err)
 	is.True(strings.Contains(string(code), `from "/bud/node_modules/svelte/internal"`))
 	is.True(strings.Contains(string(code), `element("h1");`))
@@ -68,7 +70,7 @@ func TestServeFile(t *testing.T) {
 	is.True(!strings.Contains(string(code), `hot: new Hot("http://127.0.0.1:35729/bud/hot/view/index.svelte", components)`))
 
 	// Read the wrapped version of about/index.svelte with node_modules rewritten
-	code, err = fs.ReadFile(bfs, "bud/view/about/_index.svelte.js")
+	code, err = fs.ReadFile(gfs, "bud/view/about/_index.svelte.js")
 	is.NoErr(err)
 	is.True(strings.Contains(string(code), `from "/bud/node_modules/svelte/internal"`))
 	is.True(strings.Contains(string(code), `element("h2");`))
@@ -78,7 +80,7 @@ func TestServeFile(t *testing.T) {
 	is.True(strings.Contains(string(code), `hot: new Hot("http://127.0.0.1:35729/bud/hot/view/about/index.svelte", components)`))
 
 	// Unwrapped version with node_modules rewritten
-	code, err = fs.ReadFile(bfs, "bud/view/about/index.svelte")
+	code, err = fs.ReadFile(gfs, "bud/view/about/index.svelte")
 	is.NoErr(err)
 	is.True(strings.Contains(string(code), `from "/bud/node_modules/svelte/internal"`))
 	is.True(strings.Contains(string(code), `element("h2");`))
@@ -100,10 +102,10 @@ func TestNodeModules(t *testing.T) {
 	is.NoErr(td.Write(ctx))
 	module, err := gomod.Find(dir)
 	is.NoErr(err)
-	bfs := budfs.New(module, log)
-	bfs.FileServer("bud/node_modules", dom.NodeModules(module))
+	gfs := genfs.New(dag.Discard, module, log)
+	gfs.FileServer("bud/node_modules", nodemodules.New(module))
 	// Read the re-written node_modules
-	code, err := fs.ReadFile(bfs, "bud/node_modules/svelte/internal")
+	code, err := fs.ReadFile(gfs, "bud/node_modules/svelte/internal")
 	is.NoErr(err)
 	is.True(strings.Contains(string(code), `function element(`))
 	is.True(strings.Contains(string(code), `function text(`))
@@ -124,12 +126,13 @@ func TestGenerateDir(t *testing.T) {
 	is.NoErr(err)
 	svelteCompiler, err := svelte.Load(vm)
 	is.NoErr(err)
-	transformer := transformrt.MustLoad(svelte.NewTransformable(svelteCompiler))
+	transformer, err := transformrt.Default(log, svelteCompiler)
+	is.NoErr(err)
 	module, err := gomod.Find(dir)
 	is.NoErr(err)
-	bfs := budfs.New(module, log)
-	bfs.DirGenerator("bud/view", dom.New(module, transformer.DOM))
-	des, err := fs.ReadDir(bfs, "bud/view")
+	gfs := genfs.New(dag.Discard, module, log)
+	gfs.DirGenerator("bud/view", dom.New(module, transformer))
+	des, err := fs.ReadDir(gfs, "bud/view")
 	is.NoErr(err)
 	is.Equal(len(des), 3)
 	is.Equal(des[0].Name(), "_index.svelte.js")
@@ -139,13 +142,13 @@ func TestGenerateDir(t *testing.T) {
 	is.True(strings.HasPrefix(des[2].Name(), "chunk-"))
 	is.Equal(des[2].IsDir(), false)
 	chunkName := des[2].Name()
-	des, err = fs.ReadDir(bfs, "bud/view/about")
+	des, err = fs.ReadDir(gfs, "bud/view/about")
 	is.NoErr(err)
 	is.Equal(len(des), 1)
 	is.Equal(des[0].Name(), "_index.svelte.js")
 	is.Equal(des[0].IsDir(), false)
 
-	code, err := fs.ReadFile(bfs, "bud/view/_index.svelte.js")
+	code, err := fs.ReadFile(gfs, "bud/view/_index.svelte.js")
 	is.NoErr(err)
 	is.True(strings.Contains(string(code), `"H1"`))
 	is.True(strings.Contains(string(code), `"index"`))
@@ -155,7 +158,7 @@ func TestGenerateDir(t *testing.T) {
 	// TODO: remove hot
 	// is.True(!strings.Contains(string(code), `hot:`))
 
-	code, err = fs.ReadFile(bfs, "bud/view/about/_index.svelte.js")
+	code, err = fs.ReadFile(gfs, "bud/view/about/_index.svelte.js")
 	is.NoErr(err)
 	is.True(strings.Contains(string(code), `"H2"`))
 	is.True(strings.Contains(string(code), `"about"`))
@@ -165,7 +168,7 @@ func TestGenerateDir(t *testing.T) {
 	// TODO: remove hot
 	// is.True(!strings.Contains(string(code), `hot:`))
 
-	code, err = fs.ReadFile(bfs, fmt.Sprintf("bud/view/%s", chunkName))
+	code, err = fs.ReadFile(gfs, fmt.Sprintf("bud/view/%s", chunkName))
 	is.NoErr(err)
 	is.True(strings.Contains(string(code), `"SvelteDOMInsert"`))
 	is.True(strings.Contains(string(code), `"bud_props"`))
@@ -180,9 +183,8 @@ func TestUpdateFile(t *testing.T) {
 	is.NoErr(err)
 	svelteCompiler, err := svelte.Load(vm)
 	is.NoErr(err)
-	transformer := transformrt.MustLoad(
-		svelte.NewTransformable(svelteCompiler),
-	)
+	transformer, err := transformrt.Default(log, svelteCompiler)
+	is.NoErr(err)
 	td := testdir.New(dir)
 	td.NodeModules["svelte"] = versions.Svelte
 	td.Files["view/Story.svelte"] = `<h2>Story</h2>`
@@ -196,15 +198,17 @@ func TestUpdateFile(t *testing.T) {
 	is.NoErr(td.Write(ctx))
 	module, err := gomod.Find(dir)
 	is.NoErr(err)
-	bfs := budfs.New(module, log)
-	bfs.FileServer("bud/view", dom.New(module, transformer.DOM))
+	cache, err := dag.Load(log, module.Directory("bud/bud.db"))
+	is.NoErr(err)
+	gfs := genfs.New(cache, module, log)
+	gfs.FileServer("bud/view", dom.New(module, transformer))
 	// check entry
-	code, err := fs.ReadFile(bfs, "bud/view/_index.svelte.js")
+	code, err := fs.ReadFile(gfs, "bud/view/_index.svelte.js")
 	is.NoErr(err)
 	is.True(strings.Contains(string(code), `"home"`), "missing home")
 	is.True(strings.Contains(string(code), `"Story"`), "missing Story")
 	// check component
-	code, err = fs.ReadFile(bfs, "bud/view/index.svelte")
+	code, err = fs.ReadFile(gfs, "bud/view/index.svelte")
 	is.NoErr(err)
 	is.True(strings.Contains(string(code), `"home"`), "missing home")
 	is.True(strings.Contains(string(code), `"Story"`), "missing Story")
@@ -218,24 +222,24 @@ func TestUpdateFile(t *testing.T) {
 		<Story />
 	`), 0644)
 	// check entry (cached)
-	code, err = fs.ReadFile(bfs, "bud/view/_index.svelte.js")
+	code, err = fs.ReadFile(gfs, "bud/view/_index.svelte.js")
 	is.NoErr(err)
 	is.True(strings.Contains(string(code), `"home"`), "missing home")
 	is.True(strings.Contains(string(code), `"Story"`), "missing Story")
 	// check component (cached)
-	code, err = fs.ReadFile(bfs, "bud/view/index.svelte")
+	code, err = fs.ReadFile(gfs, "bud/view/index.svelte")
 	is.NoErr(err)
 	is.True(strings.Contains(string(code), `"home"`), "missing home")
 	is.True(strings.Contains(string(code), `"Story"`), "missing Story")
 	// Mark view/Story.svelte and view/index.svelte as changed
-	bfs.Change("view/index.svelte", "view/Story.svelte")
+	is.NoErr(cache.Delete("view/index.svelte", "view/Story.svelte"))
 	// check entry (uncached)
-	code, err = fs.ReadFile(bfs, "bud/view/_index.svelte.js")
+	code, err = fs.ReadFile(gfs, "bud/view/_index.svelte.js")
 	is.NoErr(err)
 	is.True(strings.Contains(string(code), `"homies"`), "missing homies")
 	is.True(strings.Contains(string(code), `"Stories"`), "missing Stories")
 	// check component (uncached)
-	code, err = fs.ReadFile(bfs, "bud/view/index.svelte")
+	code, err = fs.ReadFile(gfs, "bud/view/index.svelte")
 	is.NoErr(err)
 	is.True(strings.Contains(string(code), `"homies"`), "missing homies")
 	is.True(strings.Contains(string(code), `"Stories"`), "missing Stories")
@@ -243,14 +247,14 @@ func TestUpdateFile(t *testing.T) {
 	// Remove a file
 	is.NoErr(os.Remove(filepath.Join(dir, "view/index.svelte")))
 	// check page (cached)
-	code, err = fs.ReadFile(bfs, "bud/view/index.svelte")
+	code, err = fs.ReadFile(gfs, "bud/view/index.svelte")
 	is.NoErr(err)
 	is.True(strings.Contains(string(code), `"homies"`), "missing homies")
 	is.True(strings.Contains(string(code), `"Stories"`), "missing Stories")
 	// Mark view/index.svelte  as changed
-	bfs.Change("view/index.svelte")
+	is.NoErr(cache.Delete("view/index.svelte"))
 	// check page (uncached)
-	code, err = fs.ReadFile(bfs, "bud/view/index.svelte")
+	code, err = fs.ReadFile(gfs, "bud/view/index.svelte")
 	is.True(errors.Is(err, fs.ErrNotExist))
 	is.Equal(code, nil)
 }
